@@ -129,7 +129,7 @@ static PlaylistSaveType save_types [] = {
 	{".XSPF", ".xspf", TOTEM_PL_PARSER_XSPF},
 };
 
-static int totem_playlist_table_signals[LAST_SIGNAL] = { 0 };
+static int totem_playlist_table_signals[LAST_SIGNAL];
 
 static const GtkTargetEntry target_table[] = {
 	{ "text/uri-list", 0, 0 },
@@ -141,7 +141,7 @@ static void playlist_copy_location_action_activated (GtkAction *action, TotemPla
 
 static const GtkActionEntry entries[] = {
 	{ "remove", GTK_STOCK_REMOVE, N_("_Remove"), NULL, N_("Remove file from playlist"), G_CALLBACK (playlist_remove_action_activated) },
-	{ "copy-location", GTK_STOCK_COPY, N_("_Copy location"), NULL, N_("Copy the location to the clipboard"), G_CALLBACK (playlist_copy_location_action_activated) }
+	{ "copy-location", GTK_STOCK_COPY, N_("_Copy Location"), NULL, N_("Copy the location to the clipboard"), G_CALLBACK (playlist_copy_location_action_activated) }
 };
 
 static void totem_playlist_class_init (TotemPlaylistClass *class);
@@ -1457,23 +1457,6 @@ totem_playlist_entry_parsed (TotemPlParser *parser,
 	totem_playlist_add_one_mrl (playlist, uri, title);
 }
 
-static void
-totem_playlist_init (TotemPlaylist *playlist)
-{
-	playlist->_priv = g_new0 (TotemPlaylistPrivate, 1);
-	playlist->_priv->parser = totem_pl_parser_new ();
-
-	totem_pl_parser_add_ignored_scheme (playlist->_priv->parser, "dvd:");
-	totem_pl_parser_add_ignored_scheme (playlist->_priv->parser, "cdda:");
-	totem_pl_parser_add_ignored_scheme (playlist->_priv->parser, "vcd:");
-	totem_pl_parser_add_ignored_scheme (playlist->_priv->parser, "cd:");
-
-	g_signal_connect (G_OBJECT (playlist->_priv->parser),
-			"entry",
-			G_CALLBACK (totem_playlist_entry_parsed),
-			playlist);
-}
-
 static void
 totem_playlist_finalize (GObject *object)
 {
@@ -1494,23 +1477,30 @@ totem_playlist_finalize (GObject *object)
 	G_OBJECT_CLASS (totem_playlist_parent_class)->finalize (object);
 }
 
-GtkWidget*
-totem_playlist_new (void)
+static void
+totem_playlist_init (TotemPlaylist *playlist)
 {
-	TotemPlaylist *playlist;
 	GtkWidget *container, *item;
 	char *filename;
 
-	playlist = TOTEM_PLAYLIST (g_object_new (TOTEM_TYPE_PLAYLIST, NULL));
+	playlist->_priv = g_new0 (TotemPlaylistPrivate, 1);
+	playlist->_priv->parser = totem_pl_parser_new ();
 
-	playlist->_priv->xml = totem_interface_load ("playlist.glade",
-			_("playlist"), TRUE, NULL);
+	totem_pl_parser_add_ignored_scheme (playlist->_priv->parser, "dvd:");
+	totem_pl_parser_add_ignored_scheme (playlist->_priv->parser, "cdda:");
+	totem_pl_parser_add_ignored_scheme (playlist->_priv->parser, "vcd:");
+	totem_pl_parser_add_ignored_scheme (playlist->_priv->parser, "cd:");
+
+	g_signal_connect (G_OBJECT (playlist->_priv->parser),
+			"entry",
+			G_CALLBACK (totem_playlist_entry_parsed),
+			playlist);
+
+	playlist->_priv->xml = totem_interface_load_with_root ("playlist.glade",
+			"vbox4", _("playlist"), TRUE, NULL);
 
 	if (playlist->_priv->xml == NULL)
-	{
-		totem_playlist_finalize (G_OBJECT (playlist));
-		return NULL;
-	}
+		return;
 
 	/* popup menu */
 	playlist->_priv->action_group = 
@@ -1527,7 +1517,7 @@ totem_playlist_new (void)
 	filename = totem_interface_get_full_path ("playlist-ui.xml");
 	if (!gtk_ui_manager_add_ui_from_file (playlist->_priv->ui_manager, filename, NULL)) {
 		totem_playlist_finalize (G_OBJECT (playlist));
-		return NULL;
+		return;
 	}
 	g_free (filename);
 
@@ -1558,10 +1548,8 @@ totem_playlist_new (void)
 			G_CALLBACK (totem_playlist_key_press), playlist);
 
 	/* Reparent the vbox */
-	item = glade_xml_get_widget (playlist->_priv->xml, "dialog-vbox1");
 	container = glade_xml_get_widget (playlist->_priv->xml, "vbox4");
 	g_object_ref (container);
-	gtk_container_remove (GTK_CONTAINER (item), container);
 	gtk_box_pack_start (GTK_BOX (playlist),
 			container,
 			TRUE,       /* expand */
@@ -1580,6 +1568,20 @@ totem_playlist_new (void)
 
 	gtk_widget_show_all (GTK_WIDGET (playlist));
 
+
+}
+
+GtkWidget*
+totem_playlist_new (void)
+{
+	TotemPlaylist *playlist;
+
+	playlist = TOTEM_PLAYLIST (g_object_new (TOTEM_TYPE_PLAYLIST, NULL));
+	if (playlist->_priv->xml == NULL || playlist->_priv->ui_manager == NULL) {
+		totem_playlist_finalize (G_OBJECT (playlist));
+		return NULL;
+	}
+
 	return GTK_WIDGET (playlist);
 }
 
