@@ -71,6 +71,23 @@ totem_action_info (char *reason, Totem *totem)
 	gtk_widget_show (error_dialog);
 }
 
+static char *
+get_stock_label (const char *stock_id)
+{
+	GtkStockItem stock_item;
+	char *label, **split;
+
+	if (gtk_stock_lookup (stock_id, &stock_item) == FALSE) {
+		g_warning ("Couldn't get stock item for '%s'", stock_id);
+		return NULL;
+	}
+	split = g_strsplit (dgettext(stock_item.translation_domain, stock_item.label),
+			      "_", 2);
+	label = g_strjoinv ("", split);
+	g_strfreev (split);
+	return label;
+}
+
 static gboolean
 ask_show_visuals (Totem *totem)
 {
@@ -427,7 +444,7 @@ totem_setup_preferences (Totem *totem)
 	GtkAction *action;
 	gboolean show_visuals, auto_resize, is_local, deinterlace;
 	int connection_speed, i;
-	char *visual, *font, *encoding;
+	char *label, *visual, *font, *encoding;
 	GList *list, *l;
 	BaconVideoWidgetAudioOutType audio_out;
 	GConfValue *value;
@@ -455,12 +472,14 @@ totem_setup_preferences (Totem *totem)
 	/* Work-around glade dialogue not parenting properly for
 	 * On top windows */
 	item = glade_xml_get_widget (totem->xml, "tpw_notebook");
-	totem->prefs = gtk_dialog_new_with_buttons ("Preferences",
+	label = get_stock_label (GTK_STOCK_PREFERENCES);
+	totem->prefs = gtk_dialog_new_with_buttons (label,
 			GTK_WINDOW (totem->win),
 			GTK_DIALOG_DESTROY_WITH_PARENT,
 			GTK_STOCK_CLOSE,
 			GTK_RESPONSE_ACCEPT,
 			NULL);
+	g_free (label);
 	gtk_dialog_set_has_separator (GTK_DIALOG (totem->prefs), FALSE);
 	gtk_container_set_border_width (GTK_CONTAINER (totem->prefs), 5);
 	gtk_box_set_spacing (GTK_BOX(GTK_DIALOG(totem->prefs)->vbox), 2);
